import javax.swing.JEditorPane;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.UIManager;

import javax.swing.JTree;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreeSelectionModel;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;

import java.net.URL;
import java.io.IOException;
import java.awt.Dimension;
import java.awt.GridLayout;

import java.io.File;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Date;

public class TreeDemo extends JPanel
                      implements TreeSelectionListener {
    private JEditorPane htmlPane;
    private JTree tree;
    private URL helpURL;
    
    private static boolean useSystemLookAndFeel = true;

    public TreeDemo(String filename) {
        super(new GridLayout(1,0));

		DefaultMutableTreeNode top = createFileNodes(new File(filename));

        //Create a tree that allows one selection at a time.
        tree = new JTree(top);
        tree.getSelectionModel().setSelectionMode
                (TreeSelectionModel.SINGLE_TREE_SELECTION);

        //Listen for when the selection changes.
        tree.addTreeSelectionListener(this);

        //Create the scroll pane and add the tree to it. 
        JScrollPane treeView = new JScrollPane(tree);

        //Create the HTML viewing pane.
        htmlPane = new JEditorPane();
        htmlPane.setEditable(false);
        initHelp();
        JScrollPane htmlView = new JScrollPane(htmlPane);

        //Add the scroll panes to a split pane.
        JSplitPane splitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT);
        splitPane.setLeftComponent(treeView);
        splitPane.setRightComponent(htmlView);

        splitPane.setPreferredSize(new Dimension(1000, 700));
		splitPane.setDividerLocation(700);

        //Add the split pane to this panel.
        add(splitPane);
    }

    /** Required by TreeSelectionListener interface. */
    public void valueChanged(TreeSelectionEvent e) {
        DefaultMutableTreeNode node = (DefaultMutableTreeNode)
                           tree.getLastSelectedPathComponent();
		
        if (node == null) return;

        Object nodeInfo = node.getUserObject();
        if (node.isLeaf()) {
            FileNode filenode = (FileNode) nodeInfo;
			
            displayURL(filenode.url);
        } else {
            displayURL(helpURL); 
        }

    }

	
	
    private class FileNode {
		public File file;
        public URL url;

        public FileNode(File _file) {
			file = _file;
			try{
			url = file.toURL(); 
			}
			catch(Exception e){System.out.println(""+e);}
        }

        public String toString() {
            return file.getName();
        }
    }
	
    private void initHelp() {
    }

    private void displayURL(URL url) {
        try {
            if (url != null) {
                htmlPane.setPage(url);
            }
        } catch (IOException e) {
            System.err.println("Attempted to read a bad URL: " + url);
        }
    }

    public static void main(String[] args) {
        if (useSystemLookAndFeel) {
            try {
                UIManager.setLookAndFeel(
                    UIManager.getSystemLookAndFeelClassName());
            } catch (Exception e) {
                System.err.println("Couldn't use system look and feel.");
            }
        }

		
		String filename = ".";
		if (args.length > 0)
			filename = args[0];
		
        //Make sure we have nice window decorations.
        JFrame.setDefaultLookAndFeelDecorated(true);

        //Create and set up the window.
        JFrame frame = new JFrame("TreeDemo");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        //Create and set up the content pane.
        TreeDemo newContentPane = new TreeDemo(filename);
        newContentPane.setOpaque(true); //content panes must be opaque
        frame.setContentPane(newContentPane);

        //Display the window.
        frame.pack();
        frame.setVisible(true);
    }

	
	public DefaultMutableTreeNode createFileNodes(File file){
		DefaultMutableTreeNode node = new DefaultMutableTreeNode(new FileNode(file));
		
        if (file.isDirectory()) {
            String[] tabFichiers = file.list();
            for (int i = 0; i < tabFichiers.length; i++) {
                File fichier = new File(file.getPath() +
                                        File.separator + tabFichiers[i]);
                node.add(createFileNodes(fichier));
            }
        }
		
		return node;
	}
	
}
